=======
History
=======
0.1.5 (2023-01-22)
------------------
* Complete documentation
* Fixed animate plot bugs
* Changed how num_interval parameter works
* Fixed warnings

0.1.4 (2022-12-19)
------------------
* Updated requirements

0.1.3 (2022-12-17)
------------------
* Bug fixes
* Some documentation added

0.1.2 (2022-11-11)
------------------

* Rename package once more to avoid confusion with R package 'visnetwork'.

0.1.1 (2022-11-11)
------------------

* Fix import errors due to package name change.

0.1.0 (2022-11-11)
------------------

* First release on PyPI.


